[PATCH] D25800: Add computeHostNumPhysicalCores() implementation for Darwin

Mehdi AMINI via llvm-commits llvm-commits at lists.llvm.org
Wed Oct 19 14:58:57 PDT 2016


mehdi_amini created this revision.
mehdi_amini added a reviewer: tejohnson.
mehdi_amini added a subscriber: llvm-commits.

https://reviews.llvm.org/D25800

Files:
  lib/Support/Host.cpp
  unittests/Support/Host.cpp


Index: lib/Support/Host.cpp
===================================================================
--- lib/Support/Host.cpp
+++ lib/Support/Host.cpp
@@ -1234,6 +1234,25 @@
   }
   return UniqueItems.size();
 }
+#elif defined(__APPLE__)
+#include <sys/param.h>
+#include <sys/sysctl.h>
+
+// Gets the number of *physical cores* on the machine.
+static int computeHostNumPhysicalCores() {
+  uint32_t count;
+  size_t len = sizeof(count);
+  sysctlbyname("hw.physicalcpu", &count, &len, NULL, 0);
+  if (count < 1) {
+    int nm[2];
+    nm[0] = CTL_HW;
+    nm[1] = HW_AVAILCPU;
+    sysctl(nm, 2, &count, &len, NULL, 0);
+    if (count < 1)
+      return -1;
+  }
+  return count;
+}
 #else
 // On other systems, return -1 to indicate unknown.
 static int computeHostNumPhysicalCores() { return -1; }


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D25800.75236.patch
Type: text/x-patch
Size: 1478 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20161019/3e128479/attachment.bin>


More information about the llvm-commits mailing list
Index: unittests/Support/Host.cpp
===================================================================
--- unittests/Support/Host.cpp
+++ unittests/Support/Host.cpp
@@ -31,9 +31,10 @@
     Host.setTriple(Triple::normalize(sys::getProcessTriple()));
 
     // Initially this is only testing detection of the number of
     // physical cores, which is currently only supported for
     // x86_64 Linux.
     SupportedArchAndOSs.push_back(std::make_pair(Triple::x86_64, Triple::Linux));
+    SupportedArchAndOSs.push_back(std::make_pair(Triple::x86_64, Triple::Darwin));
   }
 };
 
@@ -31,9 +31,10 @@
 
     // Initially this is only testing detection of the number of
-    // physical cores, which is currently only supported for
-    // x86_64 Linux.
+    // physical cores, which is currently only supported/tested for
+    // x86_64 Linux and Darwin.
     SupportedArchAndOSs.push_back(std::make_pair(Triple::x86_64, Triple::Linux));